#
# spec file for package ansible-sap-install
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ansible_collection_name sap_install
%define ansible_collection_path %{_datadir}/ansible/collections/ansible_collections/suse/%{ansible_collection_name}

Name:           ansible-sap-install
Summary:        Ansible collection suse.sap_install for SAP Automation
License:        Apache-2.0
Version:        1.6.0
Release:        1.1
URL:            https://github.com/SUSE/community.sap_install/
Source0:        %{url}archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.yaml
Source2:        transformation.py
Source99:       %{name}.rpmlintrc

BuildArch:      noarch


Requires:       ansible >= 9
Requires:       ansible-core >= 2.16
BuildRequires:  ansible >= 9
BuildRequires:  ansible-core >= 2.16

Requires:       ansible-linux-system-roles

# Python module ruamel.yaml for collection-update.py
BuildRequires:  python3-ruamel.yaml

%description
This package provides a Ansible collection suse.sap_install.

It automates the installation of various SAP software components,
 including SAP HANA, SAP NetWeaver, and SAP S/4HANA.

This collection can be used to simplify and accelerate the deployment,
management, and operation of SAP systems on Linux platforms.

%prep
%autosetup -p1 -n community.%{ansible_collection_name}-%{version}

%build
# Execute python script to update documentation and remove unsupported roles
python3 %{_sourcedir}/transformation.py --config %{_sourcedir}/%{name}.yaml  --build_dir .
# Build the Ansible collection
ansible-galaxy collection build --output-path %{_builddir}

%install
mkdir -p %{buildroot}%{_datadir}/ansible/collections
mkdir -p %{buildroot}%{_datadir}/ansible/roles/

# ansible-galaxy always appends ansible_collections folder into collections path
ansible-galaxy collection install --force %{_builddir}/suse-%{ansible_collection_name}-%{version}.tar.gz \
  --collections-path %{buildroot}%{_datadir}/ansible/collections

%post
# Loop through roles in collection and create symlinks under /usr/share/ansible/roles/
# Installed community collection will take precedence over role symlinks.
for role in %{ansible_collection_path}/roles/*; do
  role_name=$(basename "$role")
  if [ ! -e %{_datadir}/ansible/roles/community.%{ansible_collection_name}.${role_name} ]; then
    ln -sf %{ansible_collection_path}/roles/${role_name} \
      %{_datadir}/ansible/roles/community.%{ansible_collection_name}.${role_name}
  fi
done

%postun
# Loop through roles in /usr/share/ansible/roles/ and remove those that link to collection
if [ "$1" -eq 0 ]; then
  for role in %{_datadir}/ansible/roles/community.%{ansible_collection_name}.*; do
    if [ -L "$role" ]; then
      target=$(readlink "$role")
      if ( [ -e "$target" ] && [ "$target" = "%{ansible_collection_path}/roles/$(basename "$role")" ] ) || [ ! -e "$target" ]; then
        rm -f "$role"
      fi
    fi
  done
fi

%files
%{_datadir}/ansible/collections/
%{_datadir}/ansible/roles/

%changelog
* Tue Jul  8 2025 Marcel Mamula <marcel.mamula@suse.com>
- 1.6.0
  - Minor Changes:
  - New Feature - sap_anydb_install_oracle - Add handling of OS specific vars (#1033)
  - New Feature - sap_ha_pacemaker_cluster - SLES16 support, new vars for ha_cluster for corosync and zypper patterns (#1056)
  - New Feature - sap_storage_setup - Allow /software NFS mount (#1029)
  - sap_*_preconfigure - Add missing RHEL 10.x vars (#1059)
  - sap_general_preconfigure - Modify the kernel command line for SELinux also for RHEL 10 (#1036)
  - sap_general_preconfigure - Use the correct sap.conf file for RHEL 10 (#1022)
  - sap_ha_pacemaker_cluster/SUSE - SAP HANA scaleup post steps updated (#1061)
  - sap_hana_install - Add opt-out for setting sidadm to noexpire (#1016)
  - sap_swpm - Add opt-out for setting sidadm to noexpire (#1018)
  - Bugfixes:
  - Collection - fix documentation link in galaxy.yml (#1009)
  - sap_*_preconfigure - Make SELinux booleans persistent (#1013)
  - sap_*_preconfigure/SUSE - Add retry attempts to zypper pattern installation (#1032)
  - sap_*_preconfigure/SUSE - Update SLES16 pattern names and add packages for hardened images (#1057)
  - sap_ha_pacemaker_cluster/SUSE - Remove python3-rpm dependency in pre_steps_hana (#1028)
  - sap_hana_install - update README.md with Local Secure Store (LSS) installation details and examples (#1008)
  - sap_maintain_etc_hosts - Resolve situation with empty domain, but not undefined (#1044)
  - sap_swpm - Ensure sap_swpm_product_catalog_id is a string (#1035)
  - sap_swpm - Fix TEMP handling (#1019)
  - sap_swpm - Remove selinux role dependency from README.md (#1012)
  - sap_swpm - Require inifile.params only on the managed node when reusing an existing inifile.params. (#1024)
  - sap_swpm - Sanitize hostname length (#1042)
* Thu Apr 10 2025 Marcel Mamula <marcel.mamula@suse.com>
- 1.5.3
  - Initial release
  - Bugfixes:
  - collection - Cleanup the changelog(s)
  - collection - Use the correct ansible-galaxy option in README.md files
  - collection - gh issue templates
  - collection and sap_hostagent - ansible-lint fixes
  - sap*preconfigure - Use correct RHEL versions in task names
  - sap*preconfigure - sysctl checks fail when config file has comments
  - sap_*_preconfigure/SLES - Enhance saptune handling and detection
  - sap_*_preconfigure/Suse - Enhance saptune revert logic
  - sap_*_preconfigure/Suse - Switch saptune from present
  - sap_general_preconfigure - Fix check mode for sysctl
  - sap_general_preconfigure - Remove unused file configure-etc-hosts.yml
  - sap_general_preconfigure - Update the package name of the IBM Power tools for RHEL 10
  - sap_general_preconfigure - fix var role prefix
  - sap_general_preconfigure, sap_maintain_etc_hosts - Ignore comments
  - sap_general_preconfigure/SLES - Add etc hosts setup to configure steps
  - sap_ha_pacemaker_cluster - fix ASCS constraint
  - sap_ha_pacemaker_cluster - fix ASCS/ERS systemd
  - sap_ha_pacemaker_cluster - fix NWAS
  - sap_ha_pacemaker_cluster - fix internal-error
  - sap_ha_pacemaker_cluster - fix package detection on RHEL
  - sap_ha_pacemaker_cluster - fix(check-mode)
  - sap_ha_pacemaker_cluster - several bug fixes
  - sap_ha_pacemaker_cluster - stonith location constraints
  - sap_hana_install - Update fapolicyd conditionals
  - sap_hana_preconfigure - Fix check mode for largesend.conf - ppc64le
  - sap_hana_preconfigure - Update the package name of the RHEL 10 Power tools
  - sap_hana_preconfigure - fix check mode in two tasks
  - sap_hana_preconfigure/SLES - Add package libltdl7 to vars
  - sap_swpm - Fix link in README.md
  - sap_swpm - remove duplicate section credentials_anydb_ibmdb2
  - sap_swpm - removed duplicates from credentials_hana section
